import { LitElement as v, unsafeCSS as x, html as c, nothing as f } from "lit";
import { property as o } from "lit/decorators.js";
import { unsafeSVG as h } from "lit/directives/unsafe-svg.js";
import { event as g } from "../../utils/event.js";
import "../button/index.js";
const p = `:host {
  display: block;

  --dfx-alert-border-radius: var(--dfx-border-radius-l, 0.5rem);
  --dfx-alert-box-shadow: inset 0 0 0 var(--dfx-size-5xs, 0.0625rem)
    var(--dfx-alert-color-light-variant);
  --dfx-alert-color-icon: var(--dfx-alert-color-dark);
  --dfx-alert-color-background: var(--dfx-alert-color-light);
  --dfx-alert-font-family: var(
    --dfx-font-family,
    -apple-system,
    BlinkMacSystemFont,
    'Segoe UI',
    Roboto,
    Arial,
    sans-serif
  );
  --dfx-alert-font-size: var(--dfx-font-size-m, 0.875rem);
  --dfx-alert-gap: var(--dfx-size-xs, 0.75rem);
  --dfx-alert-line-height: var(--dfx-line-height-m, 1.5);
  --dfx-alert-icon-size: calc(var(--dfx-alert-line-height) * var(--dfx-alert-font-size));
  --dfx-alert-padding: var(--dfx-size-m, 1rem);
}

:host([hidden]) {
  display: none;
}

[part='alert'] {
  display: flex;
  box-sizing: border-box;
  border-radius: var(--dfx-alert-border-radius);
  background-color: var(--dfx-alert-color-background);
  font-family: var(--dfx-alert-font-family);
  font-size: var(--dfx-alert-font-size);
  line-height: var(--dfx-alert-line-height);
  box-shadow: var(--dfx-alert-box-shadow);
  padding: var(--dfx-alert-padding);
  gap: var(--dfx-alert-gap);

  [part='content'] {
    display: grid;
    width: 100%;
    gap: var(--dfx-alert-gap);
  }

  [part='icon-slot'] {
    color: var(--dfx-alert-color-icon);
    width: var(--dfx-alert-icon-size);
    height: var(--dfx-alert-icon-size);
  }
}

[part='icon-slot'] svg,
::slotted([slot='icon']) {
  width: var(--dfx-alert-icon-size);
  height: var(--dfx-alert-icon-size);
}

[part='close-button'] {
  --dfx-button-color-background-hover: var(--dfx-alert-color-light-variant);
  --dfx-button-height: var(--dfx-alert-icon-size);
  --dfx-button-line-height: calc(var(--dfx-alert-icon-size) * 0.8);
  --dfx-button-padding: calc(var(--dfx-alert-icon-size) * 0.1);
}

:host([theme='primary']) {
  --dfx-alert-color-dark: var(--dfx-color-primary-dark, #0063eb);
  --dfx-alert-color-dark-variant: var(--dfx-color-primary-dark-variant, #044cb6);
  --dfx-alert-color-light: var(--dfx-color-primary-light, #3f82f01a);
  --dfx-alert-color-light-variant: var(--dfx-color-primary-light-variant, #3f82f033);
}

:host([theme='neutral']) {
  --dfx-alert-color-dark: var(--dfx-color-neutral-dark, #4f5661);
  --dfx-alert-color-dark-variant: var(--dfx-color-neutral-dark-variant, #383d46);
  --dfx-alert-color-light: var(--dfx-color-neutral-light, #7e87951a);
  --dfx-alert-color-light-variant: var(--dfx-color-neutral-light-variant, #7e879533);
}

:host([theme='success']) {
  --dfx-alert-color-dark: var(--dfx-color-success-dark, #17843f);
  --dfx-alert-color-dark-variant: var(--dfx-color-success-dark-variant, #09672e);
  --dfx-alert-color-light: var(--dfx-color-success-light, #20a04e1a);
  --dfx-alert-color-light-variant: var(--dfx-color-success-light-variant, #20a04e33);
}

:host([theme='danger']) {
  --dfx-alert-color-dark: var(--dfx-color-danger-dark, #c91f3a);
  --dfx-alert-color-dark-variant: var(--dfx-color-danger-dark-variant, #9a1c2e);
  --dfx-alert-color-light: var(--dfx-color-danger-light, #dd4d571a);
  --dfx-alert-color-light-variant: var(--dfx-color-danger-light-variant, #dd4d5733);
}
`, u = `<svg width="100%" height="100%" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor">
  <path fill-rule="evenodd" d="M2.25 12c0-5.385 4.365-9.75 9.75-9.75s9.75 4.365 9.75 9.75-4.365 9.75-9.75 9.75S2.25 17.385 2.25 12zm11.378-3.917c-.89-.777-2.366-.777-3.255 0a.75.75 0 01-.988-1.129c1.454-1.272 3.776-1.272 5.23 0 1.513 1.324 1.513 3.518 0 4.842a3.75 3.75 0 01-.837.552c-.676.328-1.028.774-1.028 1.152v.75a.75.75 0 01-1.5 0v-.75c0-1.279 1.06-2.107 1.875-2.502.182-.088.351-.199.503-.331.83-.727.83-1.857 0-2.584zM12 18a.75.75 0 100-1.5.75.75 0 000 1.5z" clip-rule="evenodd" />
</svg>
`, m = `<svg width="100%" height="100%" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor">
  <path fill-rule="evenodd" d="M2.25 12c0-5.385 4.365-9.75 9.75-9.75s9.75 4.365 9.75 9.75-4.365 9.75-9.75 9.75S2.25 17.385 2.25 12zm8.706-1.442c1.146-.573 2.437.463 2.126 1.706l-.709 2.836.042-.02a.75.75 0 01.67 1.34l-.04.022c-1.147.573-2.438-.463-2.127-1.706l.71-2.836-.042.02a.75.75 0 11-.671-1.34l.041-.022zM12 9a.75.75 0 100-1.5.75.75 0 000 1.5z" clip-rule="evenodd" />
</svg>
`, w = `<svg width="100%" height="100%" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor">
  <path fill-rule="evenodd" d="M2.25 12c0-5.385 4.365-9.75 9.75-9.75s9.75 4.365 9.75 9.75-4.365 9.75-9.75 9.75S2.25 17.385 2.25 12zm13.36-1.814a.75.75 0 10-1.22-.872l-3.236 4.53L9.53 12.22a.75.75 0 00-1.06 1.06l2.25 2.25a.75.75 0 001.14-.094l3.75-5.25z" clip-rule="evenodd" />
</svg>
`, b = `<svg width="100%" height="100%" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor">
  <path fill-rule="evenodd" d="M12 2.25c-5.385 0-9.75 4.365-9.75 9.75s4.365 9.75 9.75 9.75 9.75-4.365 9.75-9.75S17.385 2.25 12 2.25zm-1.72 6.97a.75.75 0 10-1.06 1.06L10.94 12l-1.72 1.72a.75.75 0 101.06 1.06L12 13.06l1.72 1.72a.75.75 0 101.06-1.06L13.06 12l1.72-1.72a.75.75 0 10-1.06-1.06L12 10.94l-1.72-1.72z" clip-rule="evenodd" />
</svg>
`, k = `<svg width="100%" height="100%" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor">
  <path stroke-linecap="round" stroke-linejoin="round" d="M6 18L18 6M6 6l12 12" />
</svg>
`;
var y = Object.defineProperty, z = Object.getOwnPropertyDescriptor, t = (l, r, i, n) => {
  for (var e = n > 1 ? void 0 : n ? z(r, i) : r, d = l.length - 1, s; d >= 0; d--)
    (s = l[d]) && (e = (n ? s(r, i, e) : s(e)) || e);
  return n && e && y(r, i, e), e;
};
class a extends v {
  constructor() {
    super(...arguments), this.closable = !1, this.hidden = !1, this.theme = "neutral", this.hideIcon = !1;
  }
  static {
    this.styles = x(p);
  }
  #r(r) {
    this.hidden = !0, this.onClose.emit(r);
  }
  #e() {
    return c`
      <dfx-button
        part="close-button"
        label="Close alert"
        variant="text"
        @click=${this.#r}
      >
        ${h(k)}
      </dfx-button>
    `;
  }
  #t() {
    let r = u;
    switch (this.theme) {
      case "primary":
        r = m;
        break;
      case "success":
        r = w;
        break;
      case "danger":
        r = b;
        break;
    }
    return c`
      <div part="icon-slot">
        <slot name="icon">${h(r)}</slot>
      </div>
    `;
  }
  render() {
    return c`
      <div role="alert" part="alert">
        ${this.hideIcon ? f : this.#t()}
        <div part="content">
          <slot></slot>
        </div>
        ${this.closable ? this.#e() : f}
      </div>
    `;
  }
}
t([
  o({ type: Boolean, reflect: !0 })
], a.prototype, "closable", 2);
t([
  o({ type: Boolean, reflect: !0 })
], a.prototype, "hidden", 2);
t([
  o({ type: String, reflect: !0 })
], a.prototype, "theme", 2);
t([
  o({ type: Boolean, attribute: "hide-icon" })
], a.prototype, "hideIcon", 2);
t([
  g("dfx-close")
], a.prototype, "onClose", 2);
export {
  a as Alert
};
//# sourceMappingURL=alert.js.map
