import { LitElement as b, unsafeCSS as c, html as i, nothing as d } from "lit";
import { property as o } from "lit/decorators.js";
import { event as x } from "../../utils/event.js";
import "../spinner/spinner.js";
const h = `:host {
  display: inline-block;
  width: fit-content;

  --dfx-button-border-radius: var(--dfx-border-radius-m, 0.375rem);
  --dfx-button-focus-offset: var(--dfx-form-outline-offset, 0.2rem);
  --dfx-button-font-family: var(
    --dfx-font-family,
    -apple-system,
    BlinkMacSystemFont,
    'Segoe UI',
    Roboto,
    Arial,
    sans-serif
  );
  --dfx-button-font-size: var(--dfx-font-size-m, 0.875rem);
  --dfx-button-font-weight: var(--dfx-font-weight-semibold, 600);
  --dfx-button-gap: var(--dfx-size-2xs, 0.5rem);
  --dfx-button-height: calc(var(--dfx-button-line-height) + 2 * var(--dfx-button-padding));
  --dfx-button-icon-size: var(--dfx-button-line-height);
  --dfx-button-line-height: var(--dfx-size-l, 1.25rem);
  --dfx-button-padding: var(--dfx-size-2xs, 0.5rem);
  --dfx-button-scale-active: 0.95;
  --dfx-button-transition: all var(--dfx-transition-medium, 0.2s ease-in-out);
}

:is(a, button) {
  border: none;
  box-sizing: border-box;
  border-radius: var(--dfx-button-border-radius);
  font-family: var(--dfx-button-font-family);
  color: var(--dfx-button-color-text);
  background-color: var(--dfx-button-color-background);
  box-shadow: var(--dfx-button-shadow);
  font-size: var(--dfx-button-font-size);
  line-height: var(--dfx-button-line-height);
  font-weight: var(--dfx-button-font-weight);
  padding: var(--dfx-button-padding);
  display: flex;
  align-items: center;
  text-align: center;
  width: 100%;
  height: var(--dfx-button-height);
  transition: var(--dfx-button-transition);
  outline-offset: var(--dfx-button-focus-offset);
  text-decoration: none;
  cursor: pointer;

  &[aria-disabled='false']:hover,
  &[aria-disabled='false']:active {
    background-color: var(--dfx-button-color-background-hover);
  }

  &[aria-disabled='false']:active {
    scale: var(--dfx-button-scale-active);
  }

  &[aria-disabled='true'] {
    opacity: var(--dfx-form-disabled-opacity, 0.5);
    pointer-events: none;
  }
}

:host([hidden]) {
  display: none;
}

:host([disabled]) {
  cursor: not-allowed;
}

:host([loading]) {
  cursor: wait;
}

:host([variant='filled']) {
  --dfx-button-color-text: var(--dfx-color-contrast-text, #ffffff);
  --dfx-button-color-background: var(--dfx-button-color-dark);
  --dfx-button-color-background-hover: var(--dfx-button-color-dark-variant);
  --dfx-button-shadow: none;
}

:host([variant='tonal']) {
  --dfx-button-color-text: var(--dfx-button-color-dark-variant);
  --dfx-button-color-background: var(--dfx-button-color-light);
  --dfx-button-color-background-hover: var(--dfx-button-color-light-variant);
  --dfx-button-shadow: none;
}

:host([variant='outlined']) {
  --dfx-button-color-text: var(--dfx-button-color-dark-variant);
  --dfx-button-color-background: transparent;
  --dfx-button-color-background-hover: var(--dfx-button-color-light);
  --dfx-button-shadow: var(--dfx-form-border, inset 0 0 0 0.05rem #979fab);
}

:host([variant='text']) {
  --dfx-button-color-text: var(--dfx-button-color-dark-variant);
  --dfx-button-color-background: transparent;
  --dfx-button-color-background-hover: var(--dfx-button-color-light);
  --dfx-button-shadow: none;
}

:host([theme='primary']) {
  --dfx-button-color-dark: var(--dfx-color-primary-dark, #0063eb);
  --dfx-button-color-dark-variant: var(--dfx-color-primary-dark-variant, #044cb6);
  --dfx-button-color-light: var(--dfx-color-primary-light, #3f82f01a);
  --dfx-button-color-light-variant: var(--dfx-color-primary-light-variant, #3f82f033);
}

:host([theme='neutral']) {
  --dfx-button-color-dark: var(--dfx-color-neutral-dark, #4f5661);
  --dfx-button-color-dark-variant: var(--dfx-color-neutral-dark-variant, #383d46);
  --dfx-button-color-light: var(--dfx-color-neutral-light, #7e87951a);
  --dfx-button-color-light-variant: var(--dfx-color-neutral-light-variant, #7e879533);
}

:host([theme='success']) {
  --dfx-button-color-dark: var(--dfx-color-success-dark, #17843f);
  --dfx-button-color-dark-variant: var(--dfx-color-success-dark-variant, #09672e);
  --dfx-button-color-light: var(--dfx-color-success-light, #20a04e1a);
  --dfx-button-color-light-variant: var(--dfx-color-success-light-variant, #20a04e33);
}

:host([theme='danger']) {
  --dfx-button-color-dark: var(--dfx-color-danger-dark, #c91f3a);
  --dfx-button-color-dark-variant: var(--dfx-color-danger-dark-variant, #9a1c2e);
  --dfx-button-color-light: var(--dfx-color-danger-light, #dd4d571a);
  --dfx-button-color-light-variant: var(--dfx-color-danger-light-variant, #dd4d5733);
}

dfx-spinner {
  --dfx-spinner-size: var(--dfx-button-icon-size);
}

::slotted(svg) {
  width: var(--dfx-button-icon-size);
  height: var(--dfx-button-icon-size);
  pointer-events: none;
}

:is(a, button) {
  padding: var(--dfx-button-padding) calc(var(--dfx-button-padding) + var(--dfx-button-gap));
  gap: var(--dfx-button-gap);
}

.spinner-only,
slot:not([name])::slotted(svg) {
  margin-inline: calc(var(--dfx-button-gap) * -1);
}

.spinner-start,
slot[name='start']::slotted(*) {
  margin-inline-start: calc(var(--dfx-button-gap) * -0.5);
}

slot[name='end']::slotted(*) {
  margin-inline-end: calc(var(--dfx-button-gap) * -0.5);
}
`;
var v = Object.defineProperty, g = Object.getOwnPropertyDescriptor, t = (s, a, e, l) => {
  for (var r = l > 1 ? void 0 : l ? g(a, e) : a, f = s.length - 1, u; f >= 0; f--)
    (u = s[f]) && (r = (l ? u(a, e, r) : u(r)) || r);
  return l && r && v(a, e, r), r;
};
class n extends b {
  constructor() {
    super(...arguments), this.variant = "outlined", this.theme = "neutral", this.disabled = !1, this.loading = !1, this.type = "button";
  }
  static {
    this.styles = c(h);
  }
  #r(a) {
    if (this.type !== "button") {
      const e = this.closest("form");
      this.type === "reset" && e.reset(), this.type === "submit" && e.requestSubmit();
    }
    this.onClick.emit(a);
  }
  #t() {
    return i`<slot></slot>`;
  }
  #n() {
    return i`<slot name="start"></slot> ${this.#t()} <slot name="end"></slot>`;
  }
  #a() {
    return i`
      <div class=${this.loadingText !== "" ? "spinner-start" : "spinner-only"}>
        <dfx-spinner size="small" aria-hidden="true"></dfx-spinner>
      </div>
    `;
  }
  #o() {
    return i`
      ${this.#a()}
      ${this.loadingText !== void 0 ? this.loadingText : this.#t()}
    `;
  }
  render() {
    return this.href ? i`
          <a
            part="button"
            role="button"
            href=${this.href}
            target=${this.target ?? d}
            rel=${this.target ? "noreferrer noopener" : d}
            aria-label=${this.label ?? d}
            aria-disabled=${(this.disabled || this.loading) ?? d}
          >
            ${this.loading ? this.#o() : this.#n()}
          </a>
        ` : i`
          <button
            part="button"
            ?disabled=${this.disabled || this.loading}
            @click=${this.#r}
            aria-label=${this.label ?? d}
            aria-disabled=${(this.disabled || this.loading) ?? d}
          >
            ${this.loading ? this.#o() : this.#n()}
          </button>
        `;
  }
}
t([
  o({ type: String, reflect: !0 })
], n.prototype, "variant", 2);
t([
  o({ type: String, reflect: !0 })
], n.prototype, "theme", 2);
t([
  o({ type: String })
], n.prototype, "label", 2);
t([
  o({ type: Boolean, reflect: !0 })
], n.prototype, "disabled", 2);
t([
  o({ type: Boolean, reflect: !0 })
], n.prototype, "loading", 2);
t([
  o({ type: String, attribute: "loading-text" })
], n.prototype, "loadingText", 2);
t([
  o({ type: String })
], n.prototype, "href", 2);
t([
  o({ type: String })
], n.prototype, "target", 2);
t([
  o({ type: String })
], n.prototype, "type", 2);
t([
  x("dfx-click")
], n.prototype, "onClick", 2);
export {
  n as Button
};
//# sourceMappingURL=button.js.map
