import { LitElement, PropertyValues, TemplateResult } from 'lit';
import '../label/index.js';
declare const CheckboxGroup_base: import("@open-wc/form-control").Constructor<import("@open-wc/form-control").FormControlInterface> & typeof LitElement;
/**
 * Creates a form group of checkboxes or switches.
 *
 * @element dfx-checkbox-group
 * @slot {html} slot - Default slot for `<dfx-checkbox>` elements
 * @fires {string | null} dfx-change - Fires when value of checkbox group changes
 * @fires {ValidityState} dfx-invalid - Fires when state of checkbox group is invalid
 * @cssprop [--dfx-checkbox-group-direction=column] - Direction of checkboxes
 * @cssprop [--dfx-checkbox-group-gap=var(--dfx-size-2xs, 0.5rem)] - Gap between checkboxes
 * @csspart fieldset - Fieldset element
 * @csspart container - Container for checkboxes
 */
export declare class CheckboxGroup extends CheckboxGroup_base {
    #private;
    static styles: import("lit").CSSResult;
    /** @ignore */
    static formControlValidators: {
        attribute: string;
        key: string;
        message: () => string;
        isValid(instance: HTMLElement & {
            required: boolean;
        }, value: string): boolean;
    }[];
    /**
     * Sets label of checkbox group
     */
    label: string;
    /**
     * Sets value of checkbox group (comma-separated string of values of checked options)
     */
    value: string | null;
    /**
     * Sets name of checkbox group (when set, it shows in form data)
     */
    name: string;
    /**
     * Sets checkbox group as required
     */
    required: boolean;
    /**
     * Sets checkbox group as disabled
     */
    disabled: boolean;
    /**
     * Sets helper text of input
     */
    helperText: string;
    /**
     * Fires when value of checkbox group changes
     * @ignore
     */
    private onChange;
    /**
     * Fires when state of checkbox group is invalid
     * @ignore
     */
    private onInvalid;
    /**
     * Signals that value of checkbox group changed
     * @ignore
     */
    private dirty;
    connectedCallback(): void;
    disconnectedCallback(): void;
    validityCallback(): string;
    updated(changedProperties: PropertyValues): Promise<void>;
    resetFormControl(): void;
    firstUpdated(): void;
    render(): TemplateResult;
}
export {};
//# sourceMappingURL=checkbox-group.d.ts.map