import { LitElement, PropertyValues, TemplateResult } from 'lit';
import '../label/index.js';
declare const Checkbox_base: import("@open-wc/form-control").Constructor<import("@open-wc/form-control").FormControlInterface> & typeof LitElement;
/**
 * Allows user to select an option.
 *
 * @element dfx-checkbox
 * @slot {html} slot - Default slot for label
 * @fires {boolean} dfx-change - Fires when checkbox is checked
 * @fires {ValidityState} dfx-invalid - Fires when state of checkbox is invalid
 * @cssprop [--dfx-checkbox-border-radius=var(--dfx-border-radius-m, 0.375rem)] - Border radius
 * @cssprop [--dfx-checkbox-color=var(--dfx-color-primary-dark, #0063eb)] - Checked state color
 * @cssprop [--dfx-checkbox-check-size=var(--dfx-size-xs, 0.75rem)] - Size of checkmark icon
 * @cssprop [--dfx-checkbox-focus-offset=var(--dfx-form-outline-offset, 0.2rem)] - Checkbox focus offset
 * @cssprop [--dfx-checkbox-font-family=var(--dfx-font-family, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Arial, sans-serif)] - Label font family
 * @cssprop [--dfx-checkbox-font-size=var(--dfx-font-size-m, 0.875rem)] - Label font size
 * @cssprop [--dfx-checkbox-gap=var(--dfx-size-2xs, 0.5rem)] - Gap between checkbox and label
 * @cssprop [--dfx-checkbox-line-height=var(--dfx-line-height-m, 1.5)] - Label line height
 * @cssprop [--dfx-checkbox-size=var(--dfx-size-l, 1.25rem)] - Checkbox size
 * @cssprop [--dfx-checkbox-switch-size=var(--dfx-size-2xl, 2rem)] - Checkbox type `switch` width
 * @cssprop [--dfx-checkbox-transition=all var(--dfx-transition-medium, 0.2s ease-in-out)] - Transition
 * @csspart input - Input element
 * @csspart label - Label element
 * @csspart container - Container element
 */
export declare class Checkbox extends Checkbox_base {
    #private;
    static styles: import("lit").CSSResult;
    /** @ignore */
    static formControlValidators: {
        key: keyof ValidityState;
        isValid(instance: HTMLElement & {
            validationTarget: HTMLInputElement;
        }): boolean;
    }[];
    /** @ignore */
    validationTarget: HTMLInputElement;
    /**
     * Sets checked state of checkbox
     */
    checked: boolean;
    /**
     * Sets name of checkbox (when set, it shows in form data)
     */
    name: string;
    /**
     * Sets value of checkbox
     */
    value: string;
    /**
     * Sets type of checkbox
     */
    type: 'checkbox' | 'switch';
    /**
     * Sets checkbox as required
     */
    required: boolean;
    /**
     * Sets checkbox as disabled
     */
    disabled: boolean;
    /**
     * Sets helper text of checkbox
     */
    helperText: string;
    /**
     * Fires when checkbox is checked
     * @ignore
     */
    private onChange;
    /**
     * Fires when state of checkbox is invalid
     * @ignore
     */
    private onInvalid;
    /**
     * Signals that value of checkbox changed
     * @ignore
     */
    private dirty;
    connectedCallback(): void;
    disconnectedCallback(): void;
    validityCallback(): string;
    updated(changedProperties: PropertyValues): Promise<void>;
    resetFormControl(): void;
    focus(): void;
    render(): TemplateResult;
}
export {};
//# sourceMappingURL=checkbox.d.ts.map