import { LitElement, PropertyValues, TemplateResult } from 'lit';
import '../button/index.js';
import '../label/index.js';
import '../spinner/index.js';
declare const Input_base: import("@open-wc/form-control").Constructor<import("@open-wc/form-control").FormControlInterface> & typeof LitElement;
/**
 * Allows user to provide text input.
 *
 * @element dfx-input
 * @slot {html} start - Optional slot at the start of the control
 * @slot {html} end - Optional slot at the end of the control
 * @fires {string} dfx-input - Fires when value changed on keyup
 * @fires {string} dfx-change - Fires when value changed and input is blurred
 * @fires {ValidityState} dfx-invalid - Fires when value is invalid
 * @cssprop [--dfx-input-border-radius=var(--dfx-border-radius-m, 0.375rem)] - Border radius
 * @cssprop [--dfx-input-color-background=var(--dfx-color-background-light, #ffffff)] - Input background
 * @cssprop [--dfx-input-color-text=var(--dfx-color-text-dark, #383d46)] - Input color
 * @cssprop [--dfx-input-font-family=var(--dfx-font-family, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Arial, sans-serif)] - Input font family
 * @cssprop [--dfx-input-font-size=var(--dfx-font-size-m, 0.875rem)] - Input font size
 * @cssprop [--dfx-input-gap=calc(var(--dfx-size-xs, 0.75rem) / 2)] - Gap between items in control
 * @cssprop [--dfx-input-height=calc(var(--dfx-input-icon-size) + 2 * var(--dfx-input-padding))] - Input height
 * @cssprop [--dfx-input-icon-size=var(--dfx-size-xl, 1.5rem)] - Icon size
 * @cssprop [--dfx-input-padding=calc(var(--dfx-size-xs, 0.75rem) / 2)] - Control padding
 * @cssprop [--dfx-input-text-align=start] - Input text align
 * @cssprop [--dfx-input-transition=all var(--dfx-transition-medium, 0.2s ease-in-out)] - Input transition
 * @cssprop [--dfx-input-width=calc(var(--dfx-size-3xl, 2.5rem) * 5)] - Component width
 * @csspart input - Input element
 * @csspart control - Control element
 * @csspart container - Container element
 * @csspart button - Button element
 */
export declare class Input extends Input_base {
    #private;
    static styles: import("lit").CSSResult;
    /** @ignore */
    static formControlValidators: {
        key: keyof ValidityState;
        isValid(instance: HTMLElement & {
            validationTarget: HTMLInputElement;
        }): boolean;
    }[];
    /** @ignore */
    validationTarget: HTMLInputElement;
    /**
     * Sets name of input
     */
    name: string;
    /**
     * Sets value of input
     */
    value: string;
    /**
     * Sets type of input
     */
    type: 'date' | 'datetime-local' | 'email' | 'month' | 'number' | 'password' | 'search' | 'tel' | 'text' | 'time' | 'url' | 'week';
    /**
     * Sets label of input
     */
    label: string;
    /**
     * Sets placeholder of input
     */
    placeholder: string;
    /**
     * Sets input as required
     */
    required: boolean;
    /**
     * Sets input validation of minimum length
     */
    minlength: number;
    /**
     * Sets input validation of maximum length
     */
    maxlength: number;
    /**
     * Sets input validation of minimum value
     */
    min: number;
    /**
     * Sets input validation of maximum value
     */
    max: number;
    /**
     * Sets step of input
     */
    step: number;
    /**
     * Sets input validation by regex pattern
     */
    pattern: string;
    /**
     * Sets autocomplete of input
     */
    autocomplete: string;
    /**
     * Sets input as disabled
     */
    disabled: boolean;
    /**
     * Sets input as loading
     */
    loading: boolean;
    /**
     * Sets input as readonly
     */
    readonly: boolean;
    /**
     * Sets input mode to show correct virtual keyboard
     */
    inputmode: 'none' | 'text' | 'decimal' | 'numeric' | 'tel' | 'search' | 'email' | 'url';
    /**
     * Sets helper text of input
     */
    helperText: string;
    /**
     * Hides label of input
     */
    hideLabel: boolean;
    /**
     * Fires when value of input changed on keyup
     * @ignore
     */
    private onInput;
    /**
     * Fires when value of input changed and input is blurred
     * @ignore
     */
    private onChange;
    /**
     * Fires when value of input is invalid
     * @ignore
     */
    private onInvalid;
    /**
     * Signals that value of input changed
     * @ignore
     */
    private dirty;
    /**
     * Sets visibility of password
     * @ignore
     */
    private passwordVisible;
    connectedCallback(): void;
    disconnectedCallback(): void;
    validityCallback(): string;
    updated(changedProperties: PropertyValues): Promise<void>;
    resetFormControl(): void;
    render(): TemplateResult;
}
export {};
//# sourceMappingURL=input.d.ts.map