import { LitElement, PropertyValues, TemplateResult } from 'lit';
import '../label/index.js';
declare const Radio_base: import("@open-wc/form-control").Constructor<import("@open-wc/form-control").FormControlInterface> & typeof LitElement;
/**
 * Allows user to select a single option.
 *
 * @element dfx-radio
 * @slot {html} slot - Default slot for label
 * @fires {boolean} dfx-change - Fires when radio is checked
 * @cssprop [--dfx-radio-border-radius=var(--dfx-border-radius-full, 62.438rem)] - Border radius
 * @cssprop [--dfx-radio-color=var(--dfx-color-primary-dark, #0063eb)] - Checked state color
 * @cssprop [--dfx-radio-focus-offset=var(--dfx-form-outline-offset, 0.2rem)] - Radio focus offset
 * @cssprop [--dfx-radio-font-family=var(--dfx-font-family, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Arial, sans-serif)] - Label font family
 * @cssprop [--dfx-radio-font-size=var(--dfx-font-size-m, 0.875rem)] - Label font size
 * @cssprop [--dfx-radio-gap=var(--dfx-size-2xs, 0.5rem)] - Gap between radio and label
 * @cssprop [--dfx-radio-line-height=var(--dfx-line-height-m, 1.5)] - Label line height
 * @cssprop [--dfx-radio-size=var(--dfx-size-l, 1.25rem)] - Radio size
 * @cssprop [--dfx-radio-transition=all var(--dfx-transition-medium, 0.2s ease-in-out)] - Transition
 * @csspart input - Input element
 * @csspart label - Label element
 * @csspart container - Container element
 */
export declare class Radio extends Radio_base {
    #private;
    static styles: import("lit").CSSResult;
    /** @ignore */
    validationTarget: HTMLInputElement;
    /**
     * Sets checked state of radio
     */
    checked: boolean;
    /**
     * Sets value of radio
     */
    value: string;
    /**
     * Sets radio as disabled
     */
    disabled: boolean;
    /**
     * Sets helper text of radio
     */
    helperText: string;
    /**
     * Fires when radio is checked
     * @ignore
     */
    private onChange;
    updated(changedProperties: PropertyValues): void;
    resetFormControl(): void;
    focus(): void;
    blur(): void;
    render(): TemplateResult;
}
export {};
//# sourceMappingURL=radio.d.ts.map